/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
import { AsyncIterableObject } from '../../../base/common/async';
import { MarkdownString } from '../../../base/common/htmlContent';
import { Range } from '../../common/core/range';
import { HoverForeignElementAnchor } from '../hover/hoverTypes';
import { MarkdownHover, MarkdownHoverParticipant } from '../hover/markdownHoverParticipant';
class InlayHintsHoverAnchor extends HoverForeignElementAnchor {
    constructor(item, owner) {
        super(10, owner, Range.fromPositions(item.hint.position));
        this.item = item;
    }
}
export class InlayHintsHover extends MarkdownHoverParticipant {
    computeSync() {
        return [];
    }
    computeAsync(anchor, _lineDecorations, token) {
        if (!(anchor instanceof InlayHintsHoverAnchor)) {
            return AsyncIterableObject.EMPTY;
        }
        const { item } = anchor;
        return AsyncIterableObject.fromPromise(item.resolve(token).then(() => {
            if (!item.hint.tooltip) {
                return [];
            }
            let contents;
            if (typeof item.hint.tooltip === 'string') {
                contents = new MarkdownString().appendText(item.hint.tooltip);
            }
            else {
                contents = item.hint.tooltip;
            }
            return [new MarkdownHover(this, anchor.range, [contents], 0)];
        }));
    }
}
